.. :changelog:

History
-------

0.7 (2013-07-12)
++++++++++++++++

- Added the narwhal.get_next_open_port function, as an easy-to-use utility for
  finding an open port to use.

0.6 (2013-05-16)
++++++++++++++++

- Added an option to ``Valve`` to specify the connection framework for Repose
  to use.
